<?php
/**
 * Travelers Choice Section options
 *
 * @traveler_choice Theme Palace
 * @subtraveler_choice Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Travelers Choice section
$wp_customize->add_section( 'travel_master_pro_traveler_choice_section', array(
	'title'             => esc_html__( 'Travelers Choice','travel-master-pro' ),
	'description'       => esc_html__( 'Travelers Choice Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Travelers Choice content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_section_enable]', array(
	'default'			=> 	$options['traveler_choice_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[traveler_choice_section_enable]', array(
	'label'             => esc_html__( 'Travelers Choice Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// Travelers Choice content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_autoplay]', array(
	'default'			=> 	$options['traveler_choice_autoplay'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[traveler_choice_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
	'active_callback' 	=> 'travel_master_pro_is_traveler_choice_section_enable',
) ) );

// popular destination read more setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_read_more]', array(
	'default'			=> $options['traveler_choice_read_more'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[traveler_choice_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_traveler_choice_section',
	'active_callback' 	=> 'travel_master_pro_is_traveler_choice_section_enable',
	'type'				=> 'text',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_count]', array(
	'default'          	=> $options['traveler_choice_count'],
	'sanitize_callback' => 'travel_master_pro_sanitize_number_range',
	'validate_callback' => 'travel_master_pro_validate_traveler_choice_count',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[traveler_choice_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-master-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'active_callback'   => 'travel_master_pro_is_traveler_choice_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Travelers Choice content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]', array(
	'default'          	=> $options['traveler_choice_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[traveler_choice_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_traveler_choice_section_enable',
	'choices'			=> travel_master_pro_traveler_choice_content_type(),
) );

for ( $i=1; $i <= $options['traveler_choice_count']; $i++ ) { 
	// traveler_choice pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[traveler_choice_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_traveler_choice_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_page_enable',
	) ) );

	// traveler_choice posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[traveler_choice_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_traveler_choice_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_post_enable',
	) ) );

	// traveler_choice trips drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[traveler_choice_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[traveler_choice_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_traveler_choice_section',
		'choices'			=> travel_master_pro_trip_choices(),
		'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[traveler_choice_content_category]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[traveler_choice_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Travelers Choice selected no of posts will be shown from selected category', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[traveler_choice_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[traveler_choice_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[traveler_choice_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[traveler_choice_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[traveler_choice_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_master_pro_theme_options[traveler_choice_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_traveler_choice_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_master_pro_is_traveler_choice_section_content_destination_enable'
) ) );

